

<!doctype html>{% load i18n front_tags %}
<script src="//ajax.googleapis.com/ajax/libs/jquery/1.8.2/jquery.min.js"></script>

    {% front_edit "global" LANGUAGE_CODE %}aaa{% end_front_edit  %}
    {% front_edit_scripts editor="ace" %}
