#from django.conf import settings
from django.conf.urls import include, patterns, url
#from django.contrib import admin

#admin.autodiscover()

#from mayan.urls import urlpatterns


#urlpatterns += patterns(
#    (r'^settings_editor/', include('settings_editor.urls', namespace='settings_editor')),
#    url(r'^front-edit/', include('front.urls')),
#)
